--
-- Specialisation for MB Trac 1600 Turbo
--
-- Author: Mofi, Face, John Deere 6930

MBTrac1600Turbo = {};

function MBTrac1600Turbo.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function MBTrac1600Turbo:load(xmlFile)
    local blinkerhebelNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.blinkerhebel#index"));
    if blinkerhebelNode ~= nil then
        self.blinkerhebel = {};
        self.blinkerhebel.node = blinkerhebelNode;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.blinkerhebel#minRot"));
        self.blinkerhebel.minRot = {};
        self.blinkerhebel.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.blinkerhebel.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.blinkerhebel.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.blinkerhebel#rotLeft"));
        self.blinkerhebel.leftRot = {};
        self.blinkerhebel.leftRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.blinkerhebel.leftRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.blinkerhebel.leftRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.blinkerhebel#rotRight"));
        self.blinkerhebel.rightRot = {};
        self.blinkerhebel.rightRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.blinkerhebel.rightRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.blinkerhebel.rightRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.blinkerhebel.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.blinkerhebel#rotTime"), 1)/1000;
		self.blinkerhebel.lastDir = 1;
    end;

	self.drehzahlnadel = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.needles#rpmNeedle"));
	self.speednadel = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.needles#speedNeedle"));
	self.isSelectable = true
	
	--DURAL : damping of the rev indicator
	self.lastRotateDrehzahlnadel = 0;

end;

function MBTrac1600Turbo:delete()
end;

function MBTrac1600Turbo:readStream(streamId, connection)
end;

function MBTrac1600Turbo:writeStream(streamId, connection)
end;

function MBTrac1600Turbo:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MBTrac1600Turbo:keyEvent(unicode, sym, modifier, isDown)
end;

function MBTrac1600Turbo:update(dt)
end;

function MBTrac1600Turbo:updateTick(dt)

			if self.blinkerhebel ~= nil and self.rLights ~= nil then
				local dir = 1;
				local hasRotChanged = false;
				local destRot = self.blinkerhebel.minRot;
				if not (self.rLights.blr.a and self.rLights.bll.a) then
					if self.rLights.bll.a then
						destRot = self.blinkerhebel.leftRot;
						self.blinkerhebel.lastDir = 1;
					elseif self.rLights.blr.a then
						destRot = self.blinkerhebel.rightRot;
						self.blinkerhebel.lastDir = -1;
						dir = -1;
					else
						if not self.rLights.blr.a and not self.rLights.bll.a then
							if self.blinkerhebel.lastDir ~= -1 then
								dir = -1;
								if self.blinkerhebel.lastDir ~= 1 then
								    dir = 1;
								end;
							end;
						end;
					end;
				else
					local x,y,z = getRotation(self.blinkerhebel.node);
					if y > 0 then
						dir = -1;
					end;
				end;

				local rot = {getRotation(self.blinkerhebel.node)};
				for i=1, 3 do

					local newRot = AnimatedVehicle.getMovedLimitedValue(rot[i], destRot[i], self.blinkerhebel.rotTime*dir, dt);
					if rot[i] ~= newRot then
						hasRotChanged = true;
						rot[i] = newRot;
					end;
				end;
				if hasRotChanged then
					setRotation(self.blinkerhebel.node, unpack(rot));
				end;
			end;

		if self.isMotorStarted then
		
			--************************************************************************************************************
			--DURAL  MR "ready"
		
			--local kmh = math.min(100, math.max(0, self.lastSpeed*self.speedDisplayScale*3600));
			--local rotateDrehzahlnadel = (((kmh / 25)*100) +10);
						
			--mr
			local kmh = Utils.clamp(self.realGroundSpeed*3.6, 0, 1);			
			local rotateDrehzahlnadel = 10;		
			local rotateSpeednadel = kmh;
			
			if self.realManualGearSet then
				rotateDrehzahlnadel = 10 + self.realSoundEngineRevFx * 210;
			else
				rotateDrehzahlnadel = (self.realSoundMotorFx^0.5)*130 + 75;
			end;
			
			rotateDrehzahlnadel = math.min(280, rotateDrehzahlnadel);
			
			rotateDrehzahlnadel = 0.9*self.lastRotateDrehzahlnadel + 0.1*rotateDrehzahlnadel;
			self.lastRotateDrehzahlnadel = rotateDrehzahlnadel;
			
			
			--************************************************************************************************************
			setRotation(self.drehzahlnadel, 0, Utils.degToRad( - rotateDrehzahlnadel), 0);
			setRotation(self.speednadel, 0, Utils.degToRad( - rotateSpeednadel), 0);
		else
			setRotation(self.drehzahlnadel, 0, 0, 0);
			setRotation(self.speednadel, 0, 0, 0);
		end;
end;

function MBTrac1600Turbo:draw()
end;

